@@ -1,4 +1,4 @@
-#     Copyright 2020, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2021, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -19,10 +19,9 @@
 
 """
 
-from logging import warning
-
 from nuitka import Options
 from nuitka.__past__ import (  # pylint: disable=I0021,redefined-builtin
+    GenericAlias,
     iterItems,
     long,
     unicode,
@@ -39,6 +38,8 @@ from nuitka.Constants import (
     isHashable,
     isMutable,
 )
+from nuitka.PythonVersions import python_version
+from nuitka.Tracing import optimization_logger
 
 from .ExpressionBases import CompileTimeConstantExpressionBase
 from .IterationHandles import (
@@ -270,11 +271,13 @@ class ExpressionConstantRefBase(ExpressionConstantUntrackedRefBase):
                     max_size = 256
 
                 if max_size is not None and len(constant) > max_size:
-                    warning(
-                        "Too large constant (%s %d) encountered at %s.",
-                        type(constant),
-                        len(constant),
-                        source_ref.getAsString(),
+                    optimization_logger.warning(
+                        "Too large constant (%s %d) encountered at %s."
+                        % (
+                            type(constant),
+                            len(constant),
+                            source_ref.getAsString(),
+                        )
                     )
             except TypeError:
                 pass
@@ -379,7 +382,7 @@ class ExpressionConstantTrueRef(ExpressionConstantBoolRefBase):
 
     @staticmethod
     def getTruthValue():
-        """ Return known truth value. """
+        """Return known truth value."""
 
         return True
 
@@ -400,7 +403,7 @@ class ExpressionConstantFalseRef(ExpressionConstantBoolRefBase):
 
     @staticmethod
     def getTruthValue():
-        """ Return known truth value. """
+        """Return known truth value."""
 
         return False
 
@@ -441,7 +444,7 @@ class ExpressionConstantEllipsisRef(ExpressionConstantUntrackedRefBase):
 
     @staticmethod
     def getTruthValue():
-        """ Return known truth value. """
+        """Return known truth value."""
 
         return True
 
@@ -986,6 +989,20 @@ class ExpressionConstantStrRef(ExpressionConstantRefBase):
         return iter_node, None, None
 
 
+class ExpressionConstantStrEmptyRef(EmptyContainerMixin, ExpressionConstantStrRef):
+    kind = "EXPRESSION_CONSTANT_STR_EMPTY_REF"
+
+    __slots__ = ()
+
+    def __init__(self, user_provided, source_ref):
+        ExpressionConstantStrRef.__init__(
+            self,
+            constant="",
+            user_provided=user_provided,
+            source_ref=source_ref,
+        )
+
+
 class ExpressionConstantUnicodeRef(ExpressionConstantRefBase):
     kind = "EXPRESSION_CONSTANT_UNICODE_REF"
 
@@ -1027,6 +1044,22 @@ class ExpressionConstantUnicodeRef(ExpressionConstantRefBase):
         return iter_node, None, None
 
 
+class ExpressionConstantUnicodeEmptyRef(
+    EmptyContainerMixin, ExpressionConstantUnicodeRef
+):
+    kind = "EXPRESSION_CONSTANT_UNICODE_EMPTY_REF"
+
+    __slots__ = ()
+
+    def __init__(self, user_provided, source_ref):
+        ExpressionConstantUnicodeRef.__init__(
+            self,
+            constant=u"",
+            user_provided=user_provided,
+            source_ref=source_ref,
+        )
+
+
 class ExpressionConstantBytesRef(ExpressionConstantRefBase):
     kind = "EXPRESSION_CONSTANT_BYTES_REF"
 
@@ -1066,6 +1099,20 @@ class ExpressionConstantBytesRef(ExpressionConstantRefBase):
         return iter_node, None, None
 
 
+class ExpressionConstantBytesEmptyRef(EmptyContainerMixin, ExpressionConstantBytesRef):
+    kind = "EXPRESSION_CONSTANT_BYTES_EMPTY_REF"
+
+    __slots__ = ()
+
+    def __init__(self, user_provided, source_ref):
+        ExpressionConstantBytesRef.__init__(
+            self,
+            constant=b"",
+            user_provided=user_provided,
+            source_ref=source_ref,
+        )
+
+
 class ExpressionConstantBytearrayRef(ExpressionConstantRefBase):
     kind = "EXPRESSION_CONSTANT_BYTEARRAY_REF"
 
@@ -1300,6 +1347,27 @@ class ExpressionConstantTypeRef(ExpressionConstantUntrackedRefBase):
         return True
 
 
+class ExpressionConstantTypeSubscriptableRef(ExpressionConstantTypeRef):
+    kind = "EXPRESSION_CONSTANT_TYPE_SUBSCRIPTABLE_REF"
+
+    __slots__ = ()
+
+    def computeExpressionSubscript(self, lookup_node, subscript, trace_collection):
+        if subscript.isCompileTimeConstant():
+            return trace_collection.getCompileTimeComputationResult(
+                node=lookup_node,
+                computation=lambda: self.getCompileTimeConstant()[
+                    subscript.getCompileTimeConstant()
+                ],
+                description="Subscript of subscriptable type with constant value.",
+            )
+
+        # TODO: Not true, in fact these should become GenericAlias always.
+        trace_collection.onExceptionRaiseExit(BaseException)
+
+        return lookup_node, None, None
+
+
 def makeConstantRefNode(constant, source_ref, user_provided=False):
     # This is dispatching per constant value and types, every case
     # to be a return statement, pylint: disable=too-many-branches,too-many-return-statements,too-many-statements
@@ -1320,11 +1388,17 @@ def makeConstantRefNode(constant, source_ref, user_provided=False):
         if constant_type is int:
             return ExpressionConstantIntRef(constant=constant, source_ref=source_ref)
         elif constant_type is str:
-            return ExpressionConstantStrRef(
-                constant=constant,
-                user_provided=user_provided,
-                source_ref=source_ref,
-            )
+            if constant:
+                return ExpressionConstantStrRef(
+                    constant=constant,
+                    user_provided=user_provided,
+                    source_ref=source_ref,
+                )
+            else:
+                return ExpressionConstantStrEmptyRef(
+                    user_provided=user_provided,
+                    source_ref=source_ref,
+                )
         elif constant_type is float:
             return ExpressionConstantFloatRef(constant=constant, source_ref=source_ref)
         elif constant_type is long:
@@ -1334,17 +1408,29 @@ def makeConstantRefNode(constant, source_ref, user_provided=False):
                 source_ref=source_ref,
             )
         elif constant_type is unicode:
-            return ExpressionConstantUnicodeRef(
-                constant=constant,
-                user_provided=user_provided,
-                source_ref=source_ref,
-            )
+            if constant:
+                return ExpressionConstantUnicodeRef(
+                    constant=constant,
+                    user_provided=user_provided,
+                    source_ref=source_ref,
+                )
+            else:
+                return ExpressionConstantUnicodeEmptyRef(
+                    user_provided=user_provided,
+                    source_ref=source_ref,
+                )
         elif constant_type is bytes:
-            return ExpressionConstantBytesRef(
-                constant=constant,
-                user_provided=user_provided,
-                source_ref=source_ref,
-            )
+            if constant:
+                return ExpressionConstantBytesRef(
+                    constant=constant,
+                    user_provided=user_provided,
+                    source_ref=source_ref,
+                )
+            else:
+                return ExpressionConstantBytesEmptyRef(
+                    user_provided=user_provided,
+                    source_ref=source_ref,
+                )
         elif constant_type is dict:
             if constant:
                 assert isConstant(constant), repr(constant)
@@ -1433,6 +1519,17 @@ def makeConstantRefNode(constant, source_ref, user_provided=False):
                 source_ref=source_ref,
             )
         elif constant_type is type:
+            if python_version >= 0x390 and constant in (
+                set,
+                frozenset,
+                tuple,
+                list,
+                dict,
+            ):
+                return ExpressionConstantTypeSubscriptableRef(
+                    constant=constant, source_ref=source_ref
+                )
+
             return ExpressionConstantTypeRef(constant=constant, source_ref=source_ref)
         elif constant_type is xrange:
             return ExpressionConstantXrangeRef(
@@ -1469,6 +1566,13 @@ def makeConstantRefNode(constant, source_ref, user_provided=False):
             return ExpressionBuiltinExceptionRef(
                 exception_name=exception_name, source_ref=source_ref
             )
+        elif constant_type is GenericAlias:
+            from .BuiltinTypeNodes import ExpressionConstantGenericAlias
+
+            return ExpressionConstantGenericAlias(
+                generic_alias=constant, source_ref=source_ref
+            )
+
         else:
             # Missing constant type, ought to not happen, please report.
             assert False, (constant, constant_type)
