@@ -19,7 +19,11 @@
 
 from nuitka import Variables
 from nuitka.containers.odict import OrderedDict
-from nuitka.utils.InstanceCounters import counted_del, counted_init
+from nuitka.utils.InstanceCounters import (
+    counted_del,
+    counted_init,
+    isCountingInstances,
+)
 
 from .shapes.BuiltinTypeShapes import tshape_dict
 from .shapes.StandardShapes import tshape_unknown
@@ -88,7 +92,8 @@ class LocalsDictHandleBase(object):
 
         self.complete = False
 
-    __del__ = counted_del()
+    if isCountingInstances():
+        __del__ = counted_del()
 
     def __repr__(self):
         return "<%s of %s>" % (self.__class__.__name__, self.locals_name)
@@ -166,7 +171,7 @@ class LocalsDictHandleBase(object):
         self.providing[variable_name] = variable
 
     def unregisterProvidedVariable(self, variable):
-        """ Remove provided variable, e.g. because it became unused. """
+        """Remove provided variable, e.g. because it became unused."""
 
         variable_name = variable.getName()
 
@@ -177,17 +182,17 @@ class LocalsDictHandleBase(object):
     unregisterClosureVariable = unregisterProvidedVariable
 
     def hasProvidedVariable(self, variable_name):
-        """ Test if a variable is provided. """
+        """Test if a variable is provided."""
 
         return variable_name in self.providing
 
     def getProvidedVariable(self, variable_name):
-        """ Test if a variable is provided. """
+        """Test if a variable is provided."""
 
         return self.providing[variable_name]
 
     def getLocalsRelevantVariables(self):
-        """ The variables relevant to locals. """
+        """The variables relevant to locals."""
 
         return self.providing.values()
 
@@ -292,7 +297,7 @@ class LocalsDictHandleBase(object):
 
 
 class LocalsDictHandle(LocalsDictHandleBase):
-    """ Locals dict for a Python class with mere dict. """
+    """Locals dict for a Python class with mere dict."""
 
     __slots__ = ()
 
