@@ -1,4 +1,4 @@
-#     Copyright 2020, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2021, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -23,6 +23,7 @@ own anything by themselves. It's just a way of having try/finally for the
 expressions, or multiple returns, without running in a too different context.
 """
 
+from .ConstantRefNodes import makeConstantRefNode
 from .ExceptionNodes import ExpressionRaiseException
 from .ExpressionBases import ExpressionChildHavingBase
 from .FunctionNodes import ExpressionFunctionBodyBase
@@ -43,8 +44,6 @@ class ExpressionOutlineBody(ExpressionChildHavingBase):
     kind = "EXPRESSION_OUTLINE_BODY"
 
     named_child = "body"
-    getBody = ExpressionChildHavingBase.childGetter("body")
-    setBody = ExpressionChildHavingBase.childSetter("body")
 
     __slots__ = ("provider", "name", "temp_scope")
 
@@ -111,12 +110,12 @@ class ExpressionOutlineBody(ExpressionChildHavingBase):
         )
 
         with abort_context:
-            body = self.getBody()
+            body = self.subnode_body
 
             result = body.computeStatementsSequence(trace_collection=trace_collection)
 
             if result is not body:
-                self.setBody(result)
+                self.setChild("body", result)
                 body = result
 
             return_collections = trace_collection.getFunctionReturnCollections()
@@ -124,19 +123,29 @@ class ExpressionOutlineBody(ExpressionChildHavingBase):
         if return_collections:
             trace_collection.mergeMultipleBranches(return_collections)
 
-        first_statement = body.getStatements()[0]
+        first_statement = body.subnode_statements[0]
+
+        if first_statement.isStatementReturnConstant():
+            return (
+                makeConstantRefNode(
+                    constant=first_statement.getConstant(),
+                    source_ref=first_statement.source_ref,
+                ),
+                "new_expression",
+                "Outline '%s' is now simple return, use directly." % self.name,
+            )
 
         if first_statement.isStatementReturn():
             return (
-                first_statement.getExpression(),
+                first_statement.subnode_expression,
                 "new_expression",
                 "Outline '%s' is now simple return, use directly." % self.name,
             )
 
         if first_statement.isStatementRaiseException():
             result = ExpressionRaiseException(
-                exception_type=first_statement.getExceptionType(),
-                exception_value=first_statement.getExceptionValue(),
+                exception_type=first_statement.subnode_exception_type,
+                exception_value=first_statement.subnode_exception_value,
                 source_ref=first_statement.getSourceReference(),
             )
 
@@ -151,10 +160,10 @@ class ExpressionOutlineBody(ExpressionChildHavingBase):
         return self, None, None
 
     def mayRaiseException(self, exception_type):
-        return self.getBody().mayRaiseException(exception_type)
+        return self.subnode_body.mayRaiseException(exception_type)
 
     def willRaiseException(self, exception_type):
-        return self.getBody().willRaiseException(exception_type)
+        return self.subnode_body.willRaiseException(exception_type)
 
     def getEntryPoint(self):
         """Entry point for code.
@@ -184,6 +193,8 @@ class ExpressionOutlineFunctionBase(ExpressionFunctionBodyBase):
     Once this has no frame, it can be changed to a mere outline expression.
     """
 
+    __slots__ = ("temp_scope", "locals_scope")
+
     def __init__(self, provider, name, body, code_prefix, source_ref):
         ExpressionFunctionBodyBase.__init__(
             self,
@@ -222,12 +233,12 @@ class ExpressionOutlineFunctionBase(ExpressionFunctionBodyBase):
         )
 
         with abort_context:
-            body = self.getBody()
+            body = self.subnode_body
 
             result = body.computeStatementsSequence(trace_collection=trace_collection)
 
             if result is not body:
-                self.setBody(result)
+                self.setChild("body", result)
                 body = result
 
             return_collections = trace_collection.getFunctionReturnCollections()
@@ -235,19 +246,29 @@ class ExpressionOutlineFunctionBase(ExpressionFunctionBodyBase):
         if return_collections:
             trace_collection.mergeMultipleBranches(return_collections)
 
-        first_statement = body.getStatements()[0]
+        first_statement = body.subnode_statements[0]
+
+        if first_statement.isStatementReturnConstant():
+            return (
+                makeConstantRefNode(
+                    constant=first_statement.getConstant(),
+                    source_ref=first_statement.source_ref,
+                ),
+                "new_expression",
+                "Outline function '%s' is now simple return, use directly." % self.name,
+            )
 
         if first_statement.isStatementReturn():
             return (
-                first_statement.getExpression(),
+                first_statement.subnode_expression,
                 "new_expression",
                 "Outline function '%s' is now simple return, use directly." % self.name,
             )
 
         if first_statement.isStatementRaiseException():
             result = ExpressionRaiseException(
-                exception_type=first_statement.getExceptionType(),
-                exception_value=first_statement.getExceptionValue(),
+                exception_type=first_statement.subnode_exception_type,
+                exception_value=first_statement.subnode_exception_value,
                 source_ref=first_statement.getSourceReference(),
             )
 
@@ -262,10 +283,10 @@ class ExpressionOutlineFunctionBase(ExpressionFunctionBodyBase):
         return self, None, None
 
     def mayRaiseException(self, exception_type):
-        return self.getBody().mayRaiseException(exception_type)
+        return self.subnode_body.mayRaiseException(exception_type)
 
     def willRaiseException(self, exception_type):
-        return self.getBody().willRaiseException(exception_type)
+        return self.subnode_body.willRaiseException(exception_type)
 
     def getTraceCollection(self):
         return self.provider.getTraceCollection()
@@ -318,12 +339,14 @@ class ExpressionOutlineFunctionBase(ExpressionFunctionBodyBase):
 class ExpressionOutlineFunction(ExpressionOutlineFunctionBase):
     kind = "EXPRESSION_OUTLINE_FUNCTION"
 
+    __slots__ = ("locals_scope",)
+
     def __init__(self, provider, name, source_ref, body=None):
         ExpressionOutlineFunctionBase.__init__(
             self,
             provider=provider,
             name=name,
-            code_prefix="outline_",
+            code_prefix="outline",
             body=body,
             source_ref=source_ref,
         )
